==> zio-aws-databasemigration_2.12-7.21.15.8-sources.jar: zio/aws/databasemigration/model/DescribeEngineVersionsRequest.scala <==
package zio.aws.databasemigration.model
import zio.aws.databasemigration.model.primitives.IntegerOptional
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeEngineVersionsRequest(
    maxRecords: Optional[IntegerOptional] = Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest = {
    import DescribeEngineVersionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest
      .builder()
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.DescribeEngineVersionsRequest.ReadOnly =
    zio.aws.databasemigration.model.DescribeEngineVersionsRequest
      .wrap(buildAwsValue())
}
object DescribeEngineVersionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.DescribeEngineVersionsRequest =
      zio.aws.databasemigration.model.DescribeEngineVersionsRequest(
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def maxRecords: Optional[IntegerOptional]
    def marker: Optional[String]
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest
  ) extends zio.aws.databasemigration.model.DescribeEngineVersionsRequest.ReadOnly {
    override val maxRecords: Optional[IntegerOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.maxRecords())
      .map(value => value: IntegerOptional)
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest
  ): zio.aws.databasemigration.model.DescribeEngineVersionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-databasemigration_3-7.28.26.1-sources.jar: zio/aws/databasemigration/model/DescribeEngineVersionsRequest.scala <==
package zio.aws.databasemigration.model
import zio.aws.databasemigration.model.primitives.IntegerOptional
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class DescribeEngineVersionsRequest(
    maxRecords: Optional[IntegerOptional] = Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest = {
    import DescribeEngineVersionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest
      .builder()
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.DescribeEngineVersionsRequest.ReadOnly =
    zio.aws.databasemigration.model.DescribeEngineVersionsRequest
      .wrap(buildAwsValue())
}
object DescribeEngineVersionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.DescribeEngineVersionsRequest =
      zio.aws.databasemigration.model.DescribeEngineVersionsRequest(
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def maxRecords: Optional[IntegerOptional]
    def marker: Optional[String]
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest
  ) extends zio.aws.databasemigration.model.DescribeEngineVersionsRequest.ReadOnly {
    override val maxRecords: Optional[IntegerOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.maxRecords())
      .map(value => value: IntegerOptional)
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.DescribeEngineVersionsRequest
  ): zio.aws.databasemigration.model.DescribeEngineVersionsRequest.ReadOnly =
    new Wrapper(impl)
}
